@@ -14,7 +14,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import ugettext_lazy as _  # noqa
 
 import horizon
 
@@ -22,4 +22,3 @@ import horizon
 class Notifications(horizon.Panel):
     name = _("Notifications")
     slug = 'notifications'
-    permissions = ('openstack.roles.admin', )
